@@ -86,11 +86,11 @@ ggecdf_core <- function(data, x, y = "..ecdf..",
                       ...)
 {
 
-  p <- ggplot(data, aes_string(x))
+  p <- ggplot(data, create_aes(list(x = x)))
 
   p <- p +
       geom_exec(stat_ecdf, data = data,
-                 color = color,  size = size,
+                 color = color,  linewidth = size,
                  linetype = linetype)+
     labs(y = paste0("F(", x, ")"))
   p <- ggpar(p, palette = palette, ggtheme = ggtheme,
